@@ -4,10 +4,11 @@ Management of user-triggered asynchronous tasks in Django projects.
 
 from django.dispatch import Signal
 
-__version__ = '1.3.0'
+__version__ = '2.2.0'
 
 default_app_config = 'user_tasks.apps.UserTasksConfig'  # pylint: disable=invalid-name
 
 # This signal is emitted when a user task reaches any final state:
 # SUCCEEDED, FAILED, or CANCELED
-user_task_stopped = Signal(providing_args=['status'])  # pylint: disable=invalid-name
+# providing_args = ['status']
+user_task_stopped = Signal()  # pylint: disable=invalid-name
