@@ -7,7 +7,7 @@ from rest_framework.routers import SimpleRouter
 from user_tasks.views import ArtifactViewSet, StatusViewSet
 
 ROUTER = SimpleRouter()
-ROUTER.register(r'artifacts', ArtifactViewSet, base_name='usertaskartifact')
-ROUTER.register(r'tasks', StatusViewSet, base_name='usertaskstatus')
+ROUTER.register(r'artifacts', ArtifactViewSet, basename='usertaskartifact')
+ROUTER.register(r'tasks', StatusViewSet, basename='usertaskstatus')
 
 urlpatterns = ROUTER.urls
